<?php 
return [
  'restAPI' => [
    'fcmKey' => 'FCM Key',
  ],
  'applicationSettings' => [
    'addApplication' => 'Add Application',
    'editApplication' => 'Edit Application',
    'name' => 'name',
    'applicationCredentials' => 'Application Credentials',
    'appKey' => 'APP KEY',
    'appSecret' => 'APP SECRET',
    'note' => 'Note:',
    'secretWarning' => 'The APP SECRET key will not be accessible again. Please note it down and keep it somewhere safe.',
    'regenerateSecret' => 'Regenerate Secret',
    'status' => 'status',
  ],
];