<?php

return array(

    'form' => array(
      'email' => 'Email',
      'phone' => 'Phone',
      'gender' => 'Gender',
      'total_experience' => 'Total Experience',
      'current_location' => 'Current Location',
      'current_ctc' => 'Current CTC',
      'expected_ctc' => 'Expected CTC',
      'notice_period' => 'Notice Period',
      'application_source' => 'Application Source',
      'status' => 'Status',
      'cover_letter' => 'Cover Letter'
    ),

    'name' => array(
        'HR round' => 'HR Round',
        'Technical round' => 'Technical Round',
        'Manager round' => 'Manager Round'

    ),

    'type' => array(
      'text' => 'Text',
      'number' => 'Number',
      'password' => 'Password',
      'textarea' => 'Textarea',
      'select' => 'Select',
      'radio' => 'Radio',
      'date' => 'Date',
      'checkbox' => 'Checkbox',
      'file' => 'File'
    ),

    'skill' => array(
        'skilldepartment' => 'Skill Department',
        'skillname' => 'Skill Name',
        'fieldRequired' => 'This Field is required',
        'addSkills' => 'Skill cannot be blank.',
        'createnew' => 'Create New'
    ),

    'message' => array(
        'jobOfferStatus' => 'Job Offer',
        'mailsent' => 'Mail sent succesfully.',
        'withdraw' => 'Withdrawn succesfully.',
        'skillAdded' => 'Skill Added successfully.',
        'updateSuccess' => 'Updated successfully.',
        'deleteSuccess' => 'Deleted successfully.',
        'alreadyExist' => 'Skill name already exist.',
        'skillSame' => 'Skill name can not be same.',
        'jobApplicationAdded' => 'Job Application added successfully.',
        'interviewScheduleAdded' => 'Interview Schedule Added successfully.',
        'selectAtLeastOneEmployee' => 'Please select at-least one Employee.',
        'selectCandidate' => 'Please select candidate',
        'resumeRequired' => 'The Resume field is required',
        'termAgreement' => 'The term agreement field is required.',
        'applySuccess' => 'You have successfully applied for this position. We will get back to you very soon :)',
        'noInterview' => 'No upcoming inteview.',
        'selectStatus' => 'Please select status',
        'photoRequired' => 'The photo field is required.',
        'fullTime' => 'e.g. Full time',
        'stageSelected' => 'Stage Added successfully.'
    ),
    'job' => array(
        'startDate' => 'Start Date',
        'endDate' => 'End Date',
        'jobTitle' => 'Job Title',
        'addJob' => 'Add Job',
        'editJob' => 'Edit Job',
        'job' => 'Job',
        'jobDescription' => 'Job Description',
        'location' => 'Job Location',
        'skill' => 'Skill',
        'retrive' => 'Restore Application',
        'totalOpening' => 'Total Openings',
        'metaTitle' => 'Meta Title',
        'metaDescription' => 'Meta Description',
        'askApplicant' => 'Ask applicants for',
        'sectionVisibility' => 'Section Visibility',
        'jobRequirement' => 'Job Requirment',
        'interview' => 'Interview',
        'offerletter' => 'Offer Letter',
        'candidate' => 'Candidate',
        'history' => 'History',
        'profile' => 'Profile',
        'createJob' => 'New Job created by',
        'updateJob' => 'Job updated by',
        'createJobapplication' => 'New Job application created by',
        'updateJobapplication' => 'Job application updated by',
        'createInterview' => 'New Interview created succesfully by',
        'updateInterview' => 'Interview updated succesfully by',
        'fileActivity' => 'File is uploaded by ',
        'createEvaluation' => 'New Evaluation submitted by',
        'updateEvaluation' => 'Evaluation updated by',
        'reSchedule' => 'Interview has been Reschedule by',
        'photoRequired' => 'Photo ',
        'resumeRequired' => 'Resume ',
        'requiredColumn' => 'Required Fields',
        'createLetter' => 'New Offer Letter created succesfully by',
        'updateLetter' => 'Offer Letter updated succesfully by',
        'acceptLetter' => 'Offer letter has been accepted by',
        'declineLetter' => 'Offer letter has been declined by',
        'skillSet' => 'Skill Set',
        'noEndDate' => 'No End Date',
        'subCategory' => 'Sub Category',
        'remoteJob' => 'Is this a remote Job?',
        'discloseSalary' => 'Disclose salary on career site',
        'salaryDisclosed' => 'Salary not disclosed',
        'payAccording' => 'Pay according',
        'requiredFiled' => '<p>Selected field will be visible and considered as mandatatory field for <strong>Job Application Form</strong></p>',
        'selectJob' => 'Select Job'

    ),
    'jobApplication' => array(
        'fullName' => 'full name',
        'status' => 'Status',
        'scheduleInterview' => 'Schedule Interview',
        'archiveApplication' => 'Archive Application',
        'deleteApplication' => 'Delete Application',
        'applicantName' => 'Applicant Name',
        'applicantEmail' => 'Applicant Email',
        'applicantPhone' => 'Applicant Phone',
        'appliedAt' => 'Applied At',
        'coverLetter' => 'Cover Letter',
        'additionalDetails' => 'Additional Details',
        'applicantNotes' => 'Applicant Notes',
        'jobApplication' => 'Job Application',
        'addJobApplications' => 'Add Job Application',
        'jobs' => 'Jobs',
        'jobapplied' => 'Job Applied',
        'name' => 'Name',
        'serialNo' => 'Serial No.',
        'email' => 'Email',
        'skills' => 'Skills',
        'phone' => 'Phone',
        'gender' => 'Gender',
        'dateOfBirth' => 'Date Of Birth',
        'currentCtc'=> 'Current CTC',
        'expectedCtc'=> 'Expected CTC',
        'location' => 'Location',
        'currentStatus' => 'Current Status',
        'position' => 'Position',
        'labelColor' => 'Label Color',
        'noChange' => 'No Change',
        'columnName' => 'Column Name',
        'boardColumn' => 'Board Column',
        'jobType' => 'Job Type',
        'coverLetter' => 'Cover Letter',
        'resume' => 'Resume',
        'noNotesFound' => 'No Notes found',
        'stages' => 'Interview Rounds',
        'remarks' => 'Remarks',
        'rejectReason' => 'Reject Reason',
        'rejectApplication' => 'Reject Application',
        'action' => 'Apply model actions',
        'experience' => 'Total Experience',
        'currentLocation' => 'Current Location',
        'currentLocationPlaceholder' => 'e.g. California',
        'currentCtc' => 'Current CTC',
        'currentCtcPlaceHolder' => 'current ctc',
        'expectedCtc' => 'Expected CTC',
        'expectedCtcPlaceHolder' => 'expected ctc',
        'noticePeriod' => 'Notice Period',
        'fresher' => 'Fresher',
        'years' => 'Years',
        'over15' => 'Over 15 years',
        'over90' => 'More than 90 Days',
        'days' => 'Days',
        'below1lpa' => 'Below 1 lacs',
        'lacs' => 'lacs',
        'minimum' => 'minimum',
        'maximum' => 'maximum',
        'currentCtcMin' => 'Current CTC minimum',
        'expectedCtcMin' => 'Expected CTC minimum',
        'expectedCtcMax' => 'Expected CTC maximum',
        'currentCtcMax' => 'Current CTC maximum',
        'quickAdd' => 'Quick Add Form',
        'candidateSkills' => 'Candidate\'s Skills',
        'additionalInfo' => 'Additional Informations',
        'question' => 'Questions',
        'answers' => 'Answers',
        'additionalQuestions' => 'Additional Questions',
        'totalApplications' => 'Total Applications',
        'candidates' => 'Candidates',
        'importJobCandidates' => 'Import Job Candidates',
        'applicationNotMoved' => 'Application was not moved to this stage',
        'sendMailToJobApplicant' => 'Send Email Notification To Job Applicant',
    ),

    'interviewSchedule' => array(
        'employee' => 'Employee',
        'startDate' => 'Start Date',
        'schedule_date' => 'Schedule Date',
        'status' => 'Status',
        'addInterviewSchedule' => 'Add Interview Schedule ',
        'interview' => 'Interview',
        'candidate' => 'Candidate',
        'employee' => 'Employee',
        'interviewType' => 'Interview Type',
        'interviewScheduleDetails' => 'Interview Schedule Details',
        'meetingId' => 'Meeting ID',
        'employeeResponse' => 'Employee Response',
        'candidateEmail' => 'Candidate Email',
        'candidateName' => 'Candidate Name',
        'assignedEmployee' => 'Assigned Interviewer',
        'employeeEmail' => 'Employee Email',
        'meetingName' => 'Meeting Name',
        'meetingStatus' => 'Meeting Status',
        'allEmployees' => 'All Employees',
        'allClients' => 'All Client',
        'addEmployees' => 'Add Employees',
        'addClients' => 'Add Clients',
        'meetingId' => 'Meeting Id',
        'meetingName' => 'Meeting Title',
        'startOn' => 'Start On',
        'endOn' => 'End On',
        'addMeeting' => 'Add Meeting',
        'tableView' => 'Table View',
        'meetingName' => 'Meeting Title',
        'where' => 'where',
        'description' => 'Description (optional)',
        'addAttendees' => 'Add Attendees',
        'where' => 'Where',
        'repeat' => 'Recurring meeting',
        'repeatEvery' => 'Repeat every',
        'cycles' => 'Cycles',
        'cyclesToolTip' => 'Recurring will be stopped after the number of cycles. Keep it blank for infinity.',
        'viewAttendees' => 'Attendees',
        'remindBefore' => 'Remind before',
        'reminder' => 'Send Reminder',
        'hostVideoStatus' => 'Host Video Status',
        'participantVideoStatus' => 'Participant Video Status',
        'editMeeting' => 'Edit Meeting',
        'meetingDetails' => 'Meeting Details',
        'calendarView' => 'Calendar View',
        'startUrl' => 'Start Meeting',
        'endUrl' => 'End Meeting',
        'joinUrl' => 'Join Meeting',
        'eventName' => 'Event Name',
        'waiting' => 'Waiting',
        'live' => 'Live',
        'endMeeting' => 'End Meeting',
        'attendeeValidation' => 'Required if neither employee nor client is selected.',
        'meetingPassword' => 'Meeting Password',
        'cancelMeeting' => 'Cancel Meeting',
        'occurrence' => 'Occurrence',
        'hideFinishedMeetings' => 'Hide Finished',
        'deleteAllOccurrences' => 'Delete All Occurrences',
        'meetingHost' => 'Meeting Host',
        'meetingDetails' => 'Meeting Details',
        'recurrence' => 'Recurrence',
        'occursOn' => 'Occurs on',
        'dayOfMonth' => 'day of the month',
        'ofMonth' => ' of the month',
        'first' => 'First',
        'second' => 'Second',
        'third' => 'Third',
        'fourth' => 'Fourth',
        'last' => 'Last',
        'occurrences' => 'occurrences',
        'noFixedTime' => 'No Fixed Time',
        'startInterview' => 'Start Interview',
        'endTime' => 'End Time',
        'zoom' => 'Zoom',
        'other' => 'Other',
        'otherLink' => 'Other Link',
        'link' => 'Link',
        'videoType' => 'Video Type',
        'interviewerPhone' => 'Interviewer Phone',
        'scheduleDateTime' => 'Scheduled Date and Time',
        'scheduleDate' => 'Scheduled Date',
        'notifyCandidate' => 'Notify Candidate',
        'evaluations' => 'Evaluations',
        'evaluation' => 'Evaluation',
        'submittedBy' => 'Submitted By',
        'reSchedule' => 'Reschedule Interview',
        'interviewDetails' => 'Interview Details',
        'refused' => 'Rejected',
        'reject' => 'Reject',
        'accepted' => 'Accepted',
        'youHave' => 'You have',
        'youHad' => 'You had',
        'forJob' => 'interview schedule for',
        'with' => 'with',
        'interviewOn' => 'Interview is on',
        'interviewWasOn' => 'Interview was on',
        'scheduleResponse' => 'Employee response on Interview schedule.',
        'scheduleStatus' => 'Interview schedule changed to',
        'interviewer' => 'Interviewer',
        'interviewerName' => 'Interview Name',
        'comment' => 'Comment',
        'interviewStatus' => 'Interview Status',
        'selectRound' => 'Select round to edit',
        'awaiting' => 'Acceptance Awaited',
        'stageAndStatus' => 'Interview Round',
        'acceptInterview' => 'Accept Interview',
        'rejectInterview' => 'Reject Interview',
        'markStatusComplete' => 'Mark as Completed',
        'commentForInterviewer' => 'Comment for Interviewer',
        'commentForCandidate' => 'Comment for Candidate',
        'commentSend' => 'This comment will be send to the candidate with the notification mail',
        'stage' => 'Stage',
        'interviewdetails' => 'Interview Details',
        'pending' => 'Pending',
        'rejected' => 'Rejected',
        'hired' => 'Hired',
        'canceled' => 'Canceled',
        'completed' => 'Completed',
    ),
    'email' => array(
        'response' => 'For accept or refuse ',
        'subject' => 'Interview scheduled',
        'jobOffer' => 'Job offer letter',
        'job' => 'Job Title',
        'text' => 'Interview scheduled for Job',
        'loginDashboard' => 'Login to Dashboard',
        'thankyouNote' => 'Thank You',
        'your' => 'Your',
        'on' => 'On',
        'rescheduleText' => 'Interview has been Rescheduled for Job',
        'hostText' => 'Interview Schedule of',
        'for' => 'for Job',
        'hasBeenSchedule' => 'has been scheduled',
        'atDate' => 'Date and Time is',
        'jobCreated' => 'Job Created',
    ),
    'footerlinks' => array(
        'addfooterlinks' => 'Add Footer Link',
        'linkdetail' => 'Link Details',
        'linktitle' => 'Title',
        'slug' => 'Slug',
        'description' => 'Description',
        'title' => 'Title',
        'status' => 'Status',
        'footerdetail' => 'Footer Details',
    ),
    'front' => array(
        'apply' => 'Apply',
        'fullName' => 'Full Name',
        'email' => 'Email',
        'personalInformation' => 'Personal Information',
        'resume' => 'CV or Resume',
        'interviewSchedule' => 'Interview Schedule',
        'photo' => 'Photo',
        'termsCondition' => 'Terms And Condition',
        'agreeCondition' => 'I agree with the above Terms and Conditions',
        'skill' => 'Skills Required',
        'description' => 'Description',
        'applicationSource' => 'Application Source',
        'generalSetting' => 'General Settings',
        'noData' => 'No data found',
        'thankyou' => 'Thank You for Applying',
        'frontNote' => 'You have successfully applied for this position. We will get back to you very soon.',
        'viewJob' => 'View Job Openings',
        'source' => 'From where did you hear about us?',
        'remoteJob' => 'Remote Job',
        'salaryOffered' => 'Salary Offered',
        'totalOpenings' => 'Total Openings',
        'yourSkills' => 'Your skills',
        'createJobAlert' => 'Create Job Alert',
        'additionalDetails' => 'Additional Details',
        'shareOnWhatsapp' => 'Share on Whatsapp',
        'copyLink' => 'Copy link',
        'shareLink' => 'Share link'
    ),
    'joboffer' => array(
        'addjoboffer' => 'Add Offer Letter',
        'job' => 'Job',
        'OfferExp' => 'Offer Expire On',
        'status' => 'Status',
        'sendoffer' => 'Send',
        'reason' => 'Reason',
        'submit' => 'Submit',
        'decline' => 'Reject Reason',
        'create_emp' => 'Create Employee',
        'accpet' => 'Accepted',
        'declined' => 'Declined',
        'withdraw' => 'Withdraw',
        'candidateDetails' => 'Candidate Details',
        'jobDetails' => 'Job Details',
        'requirements' => 'Requirements',
        'offerDetail' => 'Offer Details',
        'workExperience' => 'Work Experience',
        'designation' => 'Designation',
        'offerPer' => 'Salary Offered',
        'joiningDate' => 'Joining Date',
        'lastDate' => 'Last Date of Acceptance',
        'modalTitle' => 'Modal title',
        'saveChanges' => 'Save changes',
        'frontText' => 'of work experience',
        'sendEmail' => 'Send offer letter',
        'per' => 'per',
        'payAcc' => 'Per',
        'salaryStructure' => 'Salary Structure',
        'salaryComponent' => 'Salary Components',
        'variable' => 'Variable',
        'earning' => 'Earnings',
        'basicPay' => 'Basic Salary',
        'fixedAllowance' => 'Special Allowance',
        'deduction' => 'Deductions',
        'grossEarning' => 'Gross Earnings',
        'totalDeductions' => 'Total Deductions',
        'netSalary' => 'Net Salary',
        'ctc' => 'Cost To Company',
        'modelActionMsg' => 'To create offer letter with salary structure using payroll module'
    ),
    'setting' => array(
        'legalNote' => 'Legal Term Text',
        'mailSettings' => 'Mail Settings',
        'Backgroundimage' => 'Background Image',
        'Backgroundcolor' => 'Background Color',
        'sendmail' => 'Send mail when application status changes to ',
        'backimg' => 'Background Image',
        'backcolor' => 'Background Color',
        'your' => 'Your Interview status changed to ',
        'bestview' => '(Idle Size  1120 * 200 ) ',
        'aboutCompany' => 'About Company',
        'recruiter' => 'Recruiter',
        'noRecruiter' => 'No recruiter added',
        'companyLogo' => 'Company Logo',
        'noFooter' => 'No Footer added',
        'formCheckbox' => 'Fields to be shown in Job Application Quick Add Form :-',
        'quickAddForm' => 'Quick add form settings',
        'quickAddSetting' => 'Quick Add Form Settings',
        'applicationRes' => 'Duplicate Job Application Restriction (In days)',
        'careerSiteBtn' => 'Enable Career Site',
        'offerLetterRem' => 'Offer Letter Reminder To Candidate(In days)',
        'enableCareer' => '<p>To activate the public page where your active jobs will be listed and candidate can apply for the same.</p>',
        'applicationRestri' => '<p>To <strong>restrict</strong> candidate from applying multiple times from the same email.</p><p>A candidate can apply for two different jobs from the same email but for the same job, admin can <strong>restrict</strong> them by duplicate job application restriction.</p><p>By adding <u>X</u> number of days after which you want to allow the candidate to <strong>re-apply</strong> for an particular job with the same email.</p>',
        'offerletterReminderMsg' => '<p>To <strong>Remind</strong> candidate about expiration of their offer letter.</p>
        <p>The system will send reminder mail via cron job before the <u>X</u> number of days.</p><p><u>e.g.</u> if you enter 4 days then system will send reminder email before 4 days of the offer letter expiry date </p>',
        'mailSetting' => '<p>To send email to candidate about the status change of their job application.</p><p>The system will send email to candidate only when the status change to particular status which is checked.</p>
        <p><u>e.g.</u> if Interview checked boxed is selected then the system will send email only when the status of the job application changes to interview.</p>',
        'jobAlert' => 'Job Alert',
        'alertHelp' => 'Job Alert is an <strong>email notification</strong> about the relevant jobs based on skill set and preferences which are selected by the candidate at the time job alert creation.',
        'customQuestionSettings' => 'Custom Question Settings',
        'question' => 'Question',
        'text' => 'Text',
        'file' => 'file',
        'alertForOpenings' => 'Alert for new job openings',
        'toUnsubscribe' => 'If you want to unsubscribe job alert notifications click on the given URL',
        'enterTextHere' => 'enter your text here',
        'enterPasswordHere' => 'enter your password here',
        'enterNumberHere' => 'enter digit here',
        'selectDateHere' => 'select date from here',
        'recaptcha' => '<p>ReCAPTCHA is a service that protects your website from spam and abuse.</p><p>After enabling this one will require to pass reCaptcha verfication while applying for the job.</p>',
        'statusSettings' => 'Job Applicaton Status Settings'
    ),
    'newJobApplication' => array(
        'subject' => 'New job application received',
        'text' => 'applied for job',

    ),
    'updateJobApplication' => array(
        'subject' => 'Job application updated',
        'text' => 'Job application has been updated of',
        'text2' => 'for job',
    ),
    'recruiterJobApplicationStatusChange' => array(
        'subject' => 'Job application status changed',
        'text' => 'Job application has been changed to'
    ),
    'offerAccept' => array(
        'subject' => 'Job offer accept',
        'text' => 'You have accepted offer letter for the job',
    ),
    'offerReject' => array(
        'subject' => 'Job offer reject',
        'text' => 'You have rejected offer letter for the job',
    ),

    'newJob' => array(
        'subject' => 'New job opening',
        'text' => 'Now you are a recruiter for job',
        'alertMsg' => 'There is an new job openings for',
        'lastDate' => 'last date to apply'
    ),

    'updateJob' => array(
        'subject' => 'Removed from Job',
        'subject2' => 'Job Updated',
        'text' => 'You have been removed from Job',
        'text2' => 'Job has been updated',
    ),

    'offerLetter' => array(
        'subject' => 'Offer letter created',
        'text' => 'offer letter has been created for job',
        'reminderSubject' => 'Offer Letter reminder',
        'reminderText' => 'This mail is to inform you that your offer letter is expiring on date',
        'reminderTextline' => 'Please respond accordingly.'
    ),

    'updateOffer' => array(
        'subject' => 'Offer letter updated',
        'text' => 'offer letter has been  updated for job'
    ),

    'emailNotification' => array(
        'notificationSetting' => 'Notification Settings',
        'new-jobadded-by-admin' => 'New Job (Added by Admin)',
        'new-job-applicationadded-by-admin' => 'New Job Application (Added by Admin)',
        'new-interview-scheduleadded-by-admin' => 'New Interview Schedule (Added by Admin)',
        'new-offer-letteradded-by-admin' => 'New Offer Letter (Added by Admin)',
        'notification-to-recruiter' => 'Notifications to Recruiter',
    ),

    'adminMail' => array(
        'newJobSubject' => 'New Job Created',
        'newJobText' => 'New Job has been created',
        'newJobApplicationSubject' => 'New Job Application Created',
        'updateInterviewSubject' => 'Interview Schedule Updated',
        'updateInterviewText' => 'Interview Schedule Updated for job',
        'rescheduleSubject' => 'Interview Reschedule',
    ),

    'followUpReminder' => array(
        'subject' => 'Urgent: Candidate Follow-up Reminder',
    ),
    'sourceSetting' => array(
        'addSource' => 'Add Source',
        'source' => 'Source',
        'editSource' => 'Edit Source',

    ),

);
